Settings — Stisla

# Settings

## Overview

Organize and adjust all settings about this site.

#### General

General settings such as, site title, site description, address and so on.

Change Setting

#### SEO

Search engine optimization settings, such as meta tags and social media.

Change Setting

#### Email

Email SMTP settings, notifications and others related to email.

Change Setting

#### System

PHP version settings, time zones and other environments.

Change Setting

#### Security

Security settings such as firewalls, server accounts and others.

Change Setting

#### Automation

Settings about automation such as cron job, backup automation and so on.

Change Setting